from setuptools import setup

setup(
    name='sblapi',
    version='0.1.0',
    description='API for shieldbotlist.website.',
    url='https://github.com/Shield-Bot-List/Shield-Bot-List-API/tree/py-api',
    author='fire',
    author_email='help@shieldbotlist.website',
    license='ISC',
    packages=['sblapi'],
)
